FileSystemAdapter

Struct FileSystemAdapter 

pub struct FileSystemAdapter { /* private fields */ }
Filesystem-based platform adapter.

Each instance is configured with a name and a map of EntityConfigs. All built-in adapters (claude-code, factory, gemini-cli, etc.) are instances of this struct with different configurations — the PlatformAdapter trait allows alternative implementations if needed.

Implementations

Source

impl FileSystemAdapter

pub fn new(name: &str, entities: HashMap<EntityType, EntityConfig>) -> Self