Module install

Module install 

Structs

CmdInstallOpts
InstallCtx
InstallSnapshot

Enums

InstallOutcome
Outcome of attempting to deploy one entry to one install target.
InstallSkipReason
Why an install target was skipped instead of being updated.

Functions

capture_install_snapshot
cmd_install
install_entry
install_entry_with_outcome
Returns Err(PatchConflict) if a stored patch fails to apply cleanly.